@@ -46,7 +46,6 @@
 #include "nic.h"
 /* to get the PCI support functions, if this is a PCI NIC */
 #include <gpxe/pci.h>
-#include "timer.h"
 #include "mii.h"
 
 #define drv_version "v1.12"
@@ -690,9 +689,9 @@ static int sundance_probe ( struct nic *nic, struct pci_device *pci ) {
 	}
 
 	/* Reset the chip to erase previous misconfiguration */
-	DBG ( "ASIC Control is %#lx\n", inl(BASE + ASICCtrl) );
+	DBG ( "ASIC Control is %#x\n", inl(BASE + ASICCtrl) );
 	outw(0x007f, BASE + ASICCtrl + 2);
-	DBG ( "ASIC Control is now %#lx.\n", inl(BASE + ASICCtrl) );
+	DBG ( "ASIC Control is now %#x.\n", inl(BASE + ASICCtrl) );
 
 	sundance_reset(nic);
 	if (sdc->an_enable) {
